==> freediams_0.4.2.orig.tar.gz: freediams-0.4.2/global_resources/translations/printerplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Print</name>
    <message>
        <location filename="../../plugins/printerplugin/documentprinter.cpp" line="127"/>
        <source>Made with %1.</source>
        <translation>Réalisé avec %1.</translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreferences</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="14"/>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="32"/>
        <source>Printing preferences</source>
        <translation>Préférences d&apos;impression</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="49"/>
        <source>Default printer</source>
        <translation>Imprimante par défaut</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="74"/>
        <source>Default printing options</source>
        <translation>Optionpar défaut pour l&apos;impression</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="80"/>
        <source>Resolution</source>
        <translation>Résolution</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="88"/>
        <source>Draft</source>
        <translation>Brouillon</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="93"/>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="98"/>
        <source>High</source>
        <translation>Haute</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="106"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="113"/>
        <source>Gray scale</source>
        <translation>Niveaux de gris</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="126"/>
        <source>Automated copy</source>
        <translation>Copies automatiques</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="132"/>
        <source>Always keep a PDF copy in</source>
        <translation>Toujours garder un exemplaire PDF dans</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="139"/>
        <source>Select a folder</source>
        <translation>Sélectionnez un répertoire</translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreferencesWidget</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="133"/>
        <source>WARNING !
No configurated printer found on your system.
Printing and print preview should not work at all.
Please configure a printer.
Refer to your operating system documentation.</source>
        <translation>ATTENTION !
Aucune imprimante de configurer dans votre système.
L&apos;impression et la prévisualisation de l&apos;impression ne 
fonctionneront pas.
Veuillez configurer une imprimante.
Référez-vous à la documentation de votre système d&apos;exploitation.</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="161"/>
        <source>Always use system&apos;s default printer</source>
        <translation>Toujours utiliser l&apos;imprimante système par défaut</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="165"/>
        <source>Always ask user for the printer</source>
        <translation>Toujours demander à l&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreviewerPrivate</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="44"/>
        <source>preview</source>
        <translation>prévisualisation</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="62"/>
        <source>Show page</source>
        <translation>Voir la page</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="79"/>
        <source>If it&apos;s checked the preview will update at each changes of text.
 This can be heavy CPU consuming.</source>
        <translation>Si la case est cochée alors la prévisualisation se mettra à jour à chaque changement du texte.
 Ceci peut provoquer une utilisation intensive du processeur.</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="83"/>
        <source>Automatic update</source>
        <translation>Mise à jour automatique</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="111"/>
        <source>Toogle preview</source>
        <translation>Voir/Cacher la prévisualisation</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="118"/>
        <source>Update preview</source>
        <translation>Mise à jour de la prévisualisation</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="72"/>
        <source>Show Duplicata</source>
        <translation>Montrer un duplicata</translation>
    </message>
</context>
<context>
    <name>Print::Printer</name>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="95"/>
        <source>Each Pages</source>
        <translation>Toutes les pages</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="96"/>
        <source>First page only</source>
        <translation>Première page seulement</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="97"/>
        <source>Second page only</source>
        <translation>Seconde page seulement</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="98"/>
        <source>Last page only</source>
        <translation>Dernière page seulement</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="99"/>
        <source>All pages but first</source>
        <translation>Toutes les pages sauf la première</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="100"/>
        <source>Odd pages</source>
        <translation>Pages impairs</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="101"/>
        <source>Even pages</source>
        <translation>Pages pairs</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="102"/>
        <source>Duplicatas only</source>
        <translation>Duplicatas seulement</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.cpp" line="823"/>
        <source>Print Document</source>
        <translation>Impression de document</translation>
    </message>
</context>
<context>
    <name>Print::PrinterPlugin</name>
    <message>
        <location filename="../../plugins/printerplugin/printerplugin.cpp" line="103"/>
        <source>No printer</source>
        <translation>Pas d&apos;imprimante</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerplugin.cpp" line="104"/>
        <source>No printer is configured in your system. The print preview and printing will not work.</source>
        <translation>Aucune imprimante configurée dnas votre système. La prévisualisation de l&apos;impression et l&apos;impression ne fonctionneront pas.</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerplugin.cpp" line="105"/>
        <source>You must configure at least on printer. Please refer to your system documentation. 
</source>
        <translation>Vous devez configurer au moins un imprimante. Référez-vous à la documentation de votre système d&apos;exploitation.
</translation>
    </message>
</context>
<context>
    <name>tkPrinter</name>
    <message>
        <location filename="../../plugins/printerplugin/printer.cpp" line="651"/>
        <source>No content to preview (simpleDraw).</source>
        <translation>Pas de contenu à prévisualiser (simpleDraw).</translation>
    </message>
</context>
</TS>

==> freediams_0.5.4.orig.tar.gz: freediams-0.5.4/global_resources/translations/printerplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Print</name>
    <message>
        <location filename="../../plugins/printerplugin/documentprinter.cpp" line="141"/>
        <source>Made with %1.</source>
        <translation>Réalisé avec %1.</translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrintDialog</name>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="23"/>
        <source>Print</source>
        <translation>Impression</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="106"/>
        <source>First page</source>
        <translation>Première page</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="134"/>
        <source>Previous page</source>
        <translation>Page précédente</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="156"/>
        <source># of ##</source>
        <translation># de ##</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="178"/>
        <source>Next page</source>
        <translation>Page suivante</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="206"/>
        <source>Last page</source>
        <translation>Dernière page</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="228"/>
        <source>Printer :</source>
        <translation>Imprimante :</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="248"/>
        <source>Presets :</source>
        <translation>Préréglages :</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="268"/>
        <source>Copies :</source>
        <translation>Copies :</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="284"/>
        <source>Sorted</source>
        <translation>Triées</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="294"/>
        <source>Recto Verso</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="301"/>
        <source>Pages :</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="311"/>
        <source>All</source>
        <translation>Toutes</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="320"/>
        <source>From</source>
        <translation>De</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="340"/>
        <source>to</source>
        <translation>à</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="356"/>
        <source>Print with duplicatas</source>
        <translation>Imprimer les duplicatas</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="363"/>
        <source>Two pages per paper</source>
        <translation>Deux pages par feuille</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="370"/>
        <source>Create a PDF copy in the cache directory</source>
        <translation>Crée une copie PDF dans le répertoire cache</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.cpp" line="250"/>
        <source>Save File</source>
        <translation>Sauvegarder le fichier</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.cpp" line="252"/>
        <source>PDF file (*.pdf)</source>
        <translation>Fichier PDF (*.pdf)</translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreferences</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="14"/>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="32"/>
        <source>Printing preferences</source>
        <translation>Préférences d&apos;impression</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="49"/>
        <source>Default printer</source>
        <translation>Imprimante par défaut</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="74"/>
        <source>Default printing options</source>
        <translation>Optionpar défaut pour l&apos;impression</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="80"/>
        <source>Resolution</source>
        <translation>Résolution</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="88"/>
        <source>Draft</source>
        <translation>Brouillon</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="93"/>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="98"/>
        <source>High</source>
        <translation>Haute</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="106"/>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="113"/>
        <source>Gray scale</source>
        <translation>Niveaux de gris</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="120"/>
        <source>Always print two pages per paper</source>
        <translation>Toujours imprimer deux pages par feuilles</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="133"/>
        <source>Automated copy</source>
        <translation>Copies automatiques</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="142"/>
        <source>Always keep a PDF copy in</source>
        <translation>Toujours garder un exemplaire PDF dans</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="159"/>
        <source>Select a folder</source>
        <translation>Sélectionnez un répertoire</translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreferencesWidget</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="122"/>
        <source>WARNING !
No configurated printer found on your system.
Printing and print preview should not work at all.
Please configure a printer.
Refer to your operating system documentation.</source>
        <translation>ATTENTION !
Aucune imprimante de configurer dans votre système.
L&apos;impression et la prévisualisation de l&apos;impression ne 
fonctionneront pas.
Veuillez configurer une imprimante.
Référez-vous à la documentation de votre système d&apos;exploitation.</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="150"/>
        <source>Always use system&apos;s default printer</source>
        <translation>Toujours utiliser l&apos;imprimante système par défaut</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="154"/>
        <source>Always ask user for the printer</source>
        <translation>Toujours demander à l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="225"/>
        <source>Select a directory</source>
        <translation>Sélectionnez un répertoire</translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreviewerPrivate</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="44"/>
        <source>preview</source>
        <translation>prévisualisation</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="62"/>
        <source>Show page</source>
        <translation>Voir la page</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="79"/>
        <source>If it&apos;s checked the preview will update at each changes of text.
 This can be heavy CPU consuming.</source>
        <translation>Si la case est cochée alors la prévisualisation se mettra à jour à chaque changement du texte.
 Ceci peut provoquer une utilisation intensive du processeur.</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="83"/>
        <source>Automatic update</source>
        <translation>Mise à jour automatique</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="111"/>
        <source>Toogle preview</source>
        <translation>Voir/Cacher la prévisualisation</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="118"/>
        <source>Update preview</source>
        <translation>Mise à jour de la prévisualisation</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="72"/>
        <source>Show Duplicata</source>
        <translation>Montrer un duplicata</translation>
    </message>
</context>
<context>
    <name>Print::Printer</name>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="81"/>
        <source>Each Pages</source>
        <translation>Toutes les pages</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="82"/>
        <source>First page only</source>
        <translation>Première page seulement</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="83"/>
        <source>Second page only</source>
        <translation>Seconde page seulement</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="84"/>
        <source>Last page only</source>
        <translation>Dernière page seulement</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="85"/>
        <source>All pages but first</source>
        <translation>Toutes les pages sauf la première</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="86"/>
        <source>Odd pages</source>
        <translation>Pages impairs</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="87"/>
        <source>Even pages</source>
        <translation>Pages pairs</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="88"/>
        <source>Duplicatas only</source>
        <translation>Duplicatas seulement</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.cpp" line="821"/>
        <source>Print Document</source>
        <translation>Impression de document</translation>
    </message>
</context>
<context>
    <name>Print::PrinterPlugin</name>
    <message>
        <location filename="../../plugins/printerplugin/printerplugin.cpp" line="94"/>
        <source>No printer</source>
        <translation>Pas d&apos;imprimante</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerplugin.cpp" line="95"/>
        <source>No printer is configured in your system. The print preview and printing will not work.</source>
        <translation>Aucune imprimante configurée dnas votre système. La prévisualisation de l&apos;impression et l&apos;impression ne fonctionneront pas.</translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerplugin.cpp" line="96"/>
        <source>You must configure at least on printer. Please refer to your system documentation. 
</source>
        <translation>Vous devez configurer au moins un imprimante. Référez-vous à la documentation de votre système d&apos;exploitation.
</translation>
    </message>
</context>
<context>
    <name>tkPrinter</name>
    <message>
        <location filename="../../plugins/printerplugin/printer.cpp" line="649"/>
        <source>No content to preview (simpleDraw).</source>
        <translation>Pas de contenu à prévisualiser (simpleDraw).</translation>
    </message>
</context>
</TS>
